@@ -2,7 +2,7 @@
 
 Usage: 
     ideaseed (--help | --about | --version)
-    ideaseed [options] [-t TAG...] [-l LABEL...] [-@ USERNAME...] ARGUMENTS...
+    ideaseed [options] [-t TAG...] [-l LABEL...] [-# LABEL...] [-@ USERNAME...] ARGUMENTS...
 
 Examples:
     # Save a card "test" in schoolsyst/webapp > project "UX" > column "To-Do"
@@ -18,9 +18,9 @@ Arguments:
                     If --user-keyword's value is given  Creates a card on your user's project (select which project with --user-project)
                     If given in the form OWNER/REPO     Uses the repository OWNER/REPO
                     If given in the form REPO           Uses the repository "your username/REPO"
-    PROJECT     Select a project by name to put your card to [default: REPO's value]
+    PROJECT     Select a project by name to put your card to [default: --default-project's value]
                     If creating a card on your user's project, this becomes the COLUMN
-    COLUMN      Select a project's column by name [default: To do]
+    COLUMN      Select a project's column by name [default: --default-column's value]
                     If creating a card on your user's project, this is ignored
 
 Options:
@@ -34,9 +34,11 @@ Options:
     -m --create-missing        Create non-existant tags, labels, projects or columns specified, upon confirmation.
     -o --open                  Open the relevant URL in your web browser.
     -l --label LABEL           Alias for --tag. See --tag's description.
+    -# --label LABEL           Just another shorthand for --label.
     -@ --assign-to USERNAME    Assigns users to the created issue. Only works when --issue is used.
     -M --milestone TITLE       Assign the issue to a milestone with title TITLE.
        --pin                   Pin Google Keep cards
+       --dry-run               Don't actually affect websites, put print what it would've done. Still logs in. Beware, --create-missing ignores this flag and still creates missing objects.
        --about                 Details about ideaseed like currently-installed version
        --version               Like --about, without dumb and useless stuff
 
@@ -46,6 +48,17 @@ Settings options: It's comfier to set these in your alias, e.g. alias idea="idea
        --no-auth-cache         Don't save credentials in a temporary file at {cache_filepath}
        --no-check-for-updates  Don't check for updates, don't prompt to update when current version is outdated
        --no-self-assign        Don't assign the issue to yourself
+    
+    Options beginning with --default can refer to some dynamic information using %(placeholder)s.
+    Available placeholders:
+        repository - the repository's name
+        owner      - the repository's owner
+        username   - the username of which account you are using ideaseed with
+        project    - the selected project's name (only available to --default-column)
+    
+       --default-column NAME   Set the default column name. [default: To Do]
+       --default-project NAME  Set the default project name. [default: %(repository)s]
+       
 
 Color names: Try with the first letter only too
     blue, brown, darkblue, gray, green, orange, pink, purple, red, teal, white, yellow
@@ -86,7 +99,6 @@ def run(argv=None):
         )
     )
     validate_argument_presence(args)
-    args = resolve_arguments_defaults(args)
 
     args["--tag"] += args["--label"]
     # Remove duplicate tags
@@ -98,13 +110,21 @@ def run(argv=None):
         latest_version = get_latest_version()
         if latest_version > VERSION:
             print(update_checker.notification(VERSION, latest_version))
-            if update_checker.prompt(latest_version):
+            if update_checker.prompt(VERSION, latest_version):
                 update_checker.upgrade(latest_version)
                 print(f"Re-running your command with ideaseed v{latest_version}...")
                 print("Running " + " ".join(sys.argv))
                 subprocess.run(sys.argv)
                 return
 
+    if args["--dry-run"]:
+        print(
+            dye(
+                f"\n============ Running in {dye('dry run', style='bold', fg=0xfff)} {dye('mode ============', style='dim')}\n",
+                style="dim",
+            )
+        )
+
     if args["--about"]:
         print(ABOUT_SCREEN.format(version=VERSION))
         return
@@ -146,14 +166,6 @@ def resolve_arguments(args: Dict[str, Any]) -> Dict[str, Any]:
     return {"REPO": repo, "PROJECT": project, "COLUMN": column, "IDEA": idea, **args}
 
 
-def resolve_arguments_defaults(args: Dict[str, Any]) -> Dict[str, Any]:
-    return {
-        **args,
-        "PROJECT": args["PROJECT"] or args["REPO"],
-        "COLUMN": args["COLUMN"] or "To do",
-    }
-
-
 class ValidationError(Exception):
     pass
 
@@ -169,13 +181,15 @@ def validate_argument_presence(args: Dict[str, str]) -> None:
     GITHUB_ISSUE_ONLY = ("--milestone", "--assign-to")
     using_github = len(args["ARGUMENTS"]) > 1
 
-    if using_github and not args['--issue'] and (args['--tag'] or args['--label']):
+    if using_github and not args["--issue"] and (args["--tag"] or args["--label"]):
         raise ValidationError(
             "--label (or --tag) can only be used with --issue or when creating"
             "a Google Keep card."
-        )   
+        )
 
-    if not args["--issue"] and any([ v for k, v in args.items() if k in GITHUB_ISSUE_ONLY ]):
+    if not args["--issue"] and any(
+        [v for k, v in args.items() if k in GITHUB_ISSUE_ONLY]
+    ):
         raise ValidationError(
             "The following options only work when --issue is used: "
             + ", ".join(GITHUB_ISSUE_ONLY)
